@@ -695,6 +695,7 @@ class TheBlockchainAPIResource:
         secret_recovery_phrase: str,
         derivation_path: Optional[str] = None,
         passphrase: str = str(),
+        include_gatekeeper: bool = False,
         network: SolanaNetwork = SolanaNetwork.DEVNET,
         candy_machine_contract_version: SolanaCandyMachineContractVersion = SolanaCandyMachineContractVersion.V1,
     ):
@@ -712,7 +713,8 @@ class TheBlockchainAPIResource:
             "secret_recovery_phrase": secret_recovery_phrase,
             "network": network.value,
             "passphrase": passphrase,
-            "candy_machine_contract_version": candy_machine_contract_version.value
+            "candy_machine_contract_version": candy_machine_contract_version.value,
+            "include_gatekeeper": include_gatekeeper
         }
         if derivation_path is not None:
             payload['derivation_path'] = derivation_path
